Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Magic Builder Help Window

- Now we need to add ages. You can specify ages to any level (specimen, sample, site, location). But it is most recommended to assign ages to sites. Note that you may not edit the site to location relationship in this step: to do so you will need to backtrack.
  For explanation in the different headers see: `er_ages Table`
- Insert age information under the appropriate headers.
  For Example:
  - Fill age units (under the header age_unit).
    Use controlled vocabularies from `age unit controlled vocabularies`.
  - Fill age (under the header age).
  - Fill age_range_low (under the header age_range_low).
  - Fill age_range_high (under the header age_range_high).
  - Fill age_description (under the header age_description): any text line.
  Fill geochronology method specifying dating technique (under the header magic_method_codes).
  Use controlled vocabularies from `Geochronology Method codes`.
- Er_citations should be a colon-delimited list starting with "This study" and including the DOIs for any additional citations. (see Digital Object Identification)